# Zodiax
An extension of the object-oriented Jax framework, Equinox designed to give an simplified way to interact with complex class structures and better integrate with optimisation and inference software such as Optax and Numpyro
